export interface VersionInfo {
    /**
     * The version.
     */
    readonly version: string;
}
export interface BlockMapDataHolder {
    size: number;
    blockMapSize: number;
    readonly sha512: string;
}
export interface PackageFileInfo extends BlockMapDataHolder {
    readonly path: string;
    headerSize?: number;
    blockMapData?: string;
}
export interface UpdateInfo extends VersionInfo {
    readonly path: string;
    readonly sha512: string;
    githubArtifactName?: string | null;
    /**
     * The release name.
     */
    readonly releaseName?: string | null;
    /**
     * The release notes.
     */
    readonly releaseNotes?: string | null;
    /**
     * The release date.
     */
    readonly releaseDate: string;
    /**
     * The [staged rollout](auto-update.md#staged-rollouts) percentage, 0-100.
     */
    readonly stagingPercentage?: number;
}
export interface AppImageUpdateInfo extends UpdateInfo, BlockMapDataHolder {
}
export interface WindowsUpdateInfo extends UpdateInfo {
    packages?: {
        [arch: string]: PackageFileInfo;
    } | null;
    /**
     * @deprecated
     * @private
     */
    sha2?: string;
}
